@@ -3,7 +3,7 @@ use std::fmt::Display;
 
 /// Definition of a type as a return value;
 /// e.g. `Vec<User>`, `User` or `String`
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub struct Kind {
     pub ident: Box<str>,
     pub generics: Vec<Kind>,
